IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'CONSULTA_CST' AND
	        TYPE = 'P' 			     AND
	        U.UID = O.UID           AND
	        U.NAME = USER)
DROP PROCEDURE CONSULTA_CST
GO

CREATE PROCEDURE CONSULTA_CST @P_ENTSAICST     VARCHAR(01),
                              @P_EMPRESA       VARCHAR(02),
                              @P_CDARVPROD     VARCHAR(20),
                              @P_INSCESTA      VARCHAR(16),
                              @P_TIPOOPER      VARCHAR(02),
                              @P_FILIAL        VARCHAR(14),
                              @P_LANCTONF      VARCHAR(10),
                              @P_CDGRUPOFISC   VARCHAR(03),
                              @P_IDCSTINTEREST VARCHAR(01) = 'N',
                              @P_IDCSTINTERNA  VARCHAR(01) = 'N',
                              @P_IDSISTEMA     VARCHAR(03) = NULL,
                              @P_IDORIGEMPROD  VARCHAR(01) = 'N'

AS

   DECLARE @V_SEQUENCIA    VARCHAR(02);
   DECLARE @V_CST1DIGT     VARCHAR(1);
   DECLARE @V_CDARVPROD    VARCHAR(20);
   DECLARE @V_FORNECED     VARCHAR(21);
   DECLARE @V_ORIGDESTOP   VARCHAR(1);
   DECLARE @V_EMPRESA      VARCHAR(02);
   DECLARE @V_INSCESTA     VARCHAR(16);
   DECLARE @V_CONTADOR     INTEGER;
   DECLARE @V_CONTINTEREST INTEGER;
   DECLARE @V_CONTINTERNA  INTEGER;
   DECLARE @V_CDSITUTRIB   VARCHAR(02);
   DECLARE @V_DSMENSCST    VARCHAR(120);
   DECLARE @V_COUNTMENS    INTEGER;
   DECLARE @V_CDMENSAGEM   VARCHAR(120)

   DECLARE @V_INIVALID      DATETIME;
   DECLARE @V_PAISORIG      VARCHAR(04); -- Pais de origem (utiliza UF de Origem)
   DECLARE @V_ESTAORIG      VARCHAR(02); -- Estado de origem (utiliza UF de Origem)
   DECLARE @V_MUNIORIG      VARCHAR(04); -- Municipio de origem (utiliza municipio)
   DECLARE @V_PAISDEST      VARCHAR(04);
   DECLARE @V_ESTADEST      VARCHAR(02);
   DECLARE @V_MUNIDEST      VARCHAR(04);
   DECLARE @V_IDENDCFOP     VARCHAR(01);
   DECLARE @V_IDORIGDESTNF  VARCHAR(01);
   DECLARE @V_CDCLIENTE     VARCHAR(21);
   DECLARE @V_CDORIGDESTNF  VARCHAR(21);
   DECLARE @V_IDENDEMIS     VARCHAR(01);
   DECLARE @V_CDEMPRESA     VARCHAR(02);
   DECLARE @V_CDINSCESTA    VARCHAR(16);
   DECLARE @V_CDFILIRECE    VARCHAR(04);
   DECLARE @V_CDFORNECED    VARCHAR(21);
   DECLARE @V_CDFILIEMIT    VARCHAR(04);
   DECLARE @V_VRITEM        DOUBLE PRECISION;
   DECLARE @V_EXISTE        INTEGER;

   DECLARE @V_REGRA_CDSITUTRIB    VARCHAR(02);
   DECLARE @V_REGRA_IDCSTINTEREST VARCHAR(01);
   DECLARE @V_REGRA_CDREGRAFISC   VARCHAR(10);

   DECLARE @V_IMPFILI_CDIMPOSTO   VARCHAR(02);
   DECLARE @V_IMPFILI_CDGRUPOFISC VARCHAR(03);
   DECLARE @V_IMPINSCESTAFO_CDIMPOSTO VARCHAR(02);
   DECLARE @V_IMPINSCESTAFO_CDGRUPOFISC VARCHAR(03);
   DECLARE @V_IMPINSCESTACL_CDIMPOSTO   VARCHAR(02);
   DECLARE @V_IMPINSCESTACL_CDGRUPOFISC VARCHAR(03);

   DECLARE @V_IDNFPRESTSERV VARCHAR(01);

   DECLARE @V_IDPRESENCIAL VARCHAR(01)
BEGIN

   SET @V_CST1DIGT   = NULL;
   SET @V_ORIGDESTOP = NULL;
   SET @V_EMPRESA    = NULL;
   SET @V_INSCESTA   = NULL;
   SET @V_FORNECED   = NULL;
   SET @V_CDARVPROD  = NULL;
   SET @V_CONTADOR   = 0;

   DELETE FROM CSTTEMP
   WHERE NRCSTTEMP = @P_FILIAL + @P_LANCTONF;

   /*CONDIO COLOCADA PARA EVITAR ERROS COM O NULL EM SQL SERVER*/
   IF @P_CDARVPROD IS NULL BEGIN
      SET @P_CDARVPROD = 'NULL'
   END;

   IF @P_ENTSAICST = 'S' BEGIN
      SELECT @V_CST1DIGT = MAX(CDCSTDIG1PROD)
        FROM PRODUTO
       WHERE (CDARVPROD = @P_CDARVPROD);

      IF @V_CST1DIGT IS NULL BEGIN
         SELECT @V_CST1DIGT = MAX(CDCSTDIG1SAI)
         FROM INSCRESTAD
         WHERE (CDEMPRESA  = @P_EMPRESA) AND
               (CDINSCESTA = @P_INSCESTA);
      END;
   END
   ELSE BEGIN
      SELECT @V_ORIGDESTOP = MAX(IDORIGDESTOP),
             @V_IDNFPRESTSERV = ISNULL(MAX(IDNFPRESTSERV), 'N')
      FROM TIPOOPERAC
      WHERE CDTIPOOPER     = @P_TIPOOPER AND
            IDENTRSAIDOP   = 'E';

      IF @V_ORIGDESTOP = 'L' BEGIN
         SELECT @V_EMPRESA = MAX(CDEMPRESA), @V_INSCESTA = MAX(CDINSCESTA)
         FROM FILIAL
         WHERE CDFILIAL IN (SELECT CDFILIRECE
                            FROM NOTAFISCAL
                            WHERE CDFILIAL   = @P_FILIAL   AND
                                  NRLANCTONF = @P_LANCTONF AND
                                  @P_IDSISTEMA IS NULL
                            UNION ALL
                            SELECT CDFILIALPED
                            FROM PEDIDO
                            WHERE CDFILIAL = SUBSTRING(@P_FILIAL,1,4) AND
                                  NRPEDIDO = SUBSTRING(@P_FILIAL,5,10) AND
                                  @P_IDSISTEMA = 'PED');

         SELECT @V_CST1DIGT = MAX(CDCSTDIG1PROD)
           FROM PRODUTO
          WHERE (CDARVPROD  = @P_CDARVPROD);

         IF @V_CST1DIGT IS NULL BEGIN
            SELECT @V_CST1DIGT = MAX(CDCSTDIG1SAI)
              FROM INSCRESTAD
             WHERE CDEMPRESA   = @V_EMPRESA AND
                   CDINSCESTA  = @V_INSCESTA;
         END;
      END
      ELSE IF @V_ORIGDESTOP = 'C'
      BEGIN
         SELECT @V_CST1DIGT = MAX(CDCSTDIG1PROD)
           FROM PRODUTO
          WHERE (CDARVPROD  = @P_CDARVPROD);

         IF @V_CST1DIGT IS NULL BEGIN
            SELECT @V_CST1DIGT  = MAX(CDCSTDIG1CLI)
              FROM NOTAFISCAL N LEFT JOIN CLIENTE C
                               ON (N.CDCLIENTE = C.CDCLIENTE)
             WHERE (CDFILIAL     = @P_FILIAL) AND
                   (NRLANCTONF   = @P_LANCTONF);
         END;
      END
      ELSE
      BEGIN
         SELECT @V_CST1DIGT = MAX(CDCSTDIG1PROD)
           FROM PRODUTO
          WHERE (CDARVPROD  = @P_CDARVPROD);

         IF @V_CST1DIGT IS NULL BEGIN
            SELECT @V_FORNECED = MAX(CDFORNECED)
              FROM NOTAFISCAL
             WHERE CDFILIAL     = @P_FILIAL AND
                   NRLANCTONF   = @P_LANCTONF;

            SELECT @V_CST1DIGT = MAX(CDCSTDIG1ENT)
              FROM FORNECEDOR
             WHERE (CDFORNECED = @V_FORNECED);
         END;
      END;
   END;

   SET @V_SEQUENCIA = '01';


   SELECT @V_INIVALID = MAX(N.DTENTRSAID), 
          @V_CDFILIEMIT = MAX(N.CDFILIEMIT), 
          @V_IDORIGDESTNF = MAX(N.IDORIGDESTNF), 
          @V_CDCLIENTE = MAX(N.CDCLIENTE),
          @V_CDFILIRECE = MAX(N.CDFILIRECE), 
          @V_CDFORNECED = MAX(N.CDFORNECED), 
          @V_VRITEM = (MAX(IT.VRTOTAITEM) - MAX(IT.VRDESCITEM)),
          @V_IDPRESENCIAL = ISNULL(MAX(N.IDPRESENCIAL), '9')
     FROM NOTAFISCAL N, ITEMPRODUTO IT, PRODUTO P
    WHERE N.CDFILIAL = @P_FILIAL
      AND N.NRLANCTONF = @P_LANCTONF
      AND N.CDFILIAL = IT.CDFILIAL
      AND N.NRLANCTONF = IT.NRLANCTONF
      AND IT.CDPRODUTO = P.CDPRODUTO
      AND P.CDARVPROD  = @P_CDARVPROD;

   IF (@P_ENTSAICST = 'S') BEGIN

         SET @V_IDENDCFOP  = 'I';
         SET @V_CDEMPRESA  = Null;
         SET @V_CDINSCESTA = Null;

         SELECT @V_IDENDCFOP = ISNULL(IDENDCFOPFIL,'I'),
                @V_CDEMPRESA = CDEMPRESA,
                @V_CDINSCESTA = CDINSCESTA
         FROM FILIAL
         WHERE (CDFILIAL = @V_CDFILIEMIT);

      IF @V_IDENDCFOP = 'I' BEGIN
         SET @V_PAISORIG = Null;
         SET @V_ESTAORIG = Null;
         SET @V_MUNIORIG = Null;

         SELECT @V_PAISORIG = CDPAIS, @V_ESTAORIG = SGESTADO, @V_MUNIORIG = CDMUNICIPIO
         FROM INSCRESTAD
         WHERE CDEMPRESA  = @P_EMPRESA AND
               CDINSCESTA = @P_INSCESTA;
      END
      ELSE BEGIN
         SET @V_PAISORIG = Null;
         SET @V_ESTAORIG = Null;
         SET @V_MUNIORIG = Null;

         SELECT @V_PAISORIG = CDPAIS, @V_ESTAORIG = SGESTADO, @V_MUNIORIG = CDMUNICIPIO
         FROM ENDEFILI
         WHERE (CDFILIAL     = @V_CDFILIEMIT) AND
               (IDTPENDEFILI = @V_IDENDCFOP);
      END;

      /*DESTINATRIO-REMETENTE DA NOTA*/
      IF @V_IDORIGDESTNF IS NULL BEGIN
         SET @V_ORIGDESTOP = Null;

         SELECT @V_ORIGDESTOP = IDORIGDESTOP
         FROM TIPOOPERAC
         WHERE IDENTRSAIDOP = 'S' AND
               CDTIPOOPER   = @P_TIPOOPER;
      END
      ELSE BEGIN
         SET @V_ORIGDESTOP = @V_IDORIGDESTNF;
      END;

      IF @V_ORIGDESTOP = 'L' BEGIN /*DESTINATARIO -> FILIAL */
         SET @V_CDORIGDESTNF = @V_CDFILIRECE;

         SET @V_IDENDCFOP  = 'I';
         SET @V_IDENDEMIS  = 'I';
         SET @V_CDEMPRESA  = Null;
         SET @V_CDINSCESTA = Null;

         SELECT @V_IDENDCFOP = ISNULL(IDENDCFOPFIL,'I'), @V_IDENDEMIS = ISNULL(IDENDEMISFIL,'I'),
                @V_CDEMPRESA = CDEMPRESA, @V_CDINSCESTA = CDINSCESTA
         FROM FILIAL
         WHERE (CDFILIAL = @V_CDFILIRECE);

         IF @V_IDENDEMIS = 'I' BEGIN
            SET @V_PAISDEST = Null;
            SET @V_ESTADEST = Null;
            SET @V_MUNIDEST = Null;

            SELECT @V_PAISDEST = CDPAIS, @V_ESTADEST = SGESTADO, @V_MUNIDEST = CDMUNICIPIO
            FROM INSCRESTAD
            WHERE CDEMPRESA  = @V_CDEMPRESA AND
                  CDINSCESTA = @V_CDINSCESTA;
         END
         ELSE BEGIN
            SET @V_PAISDEST = Null;
            SET @V_ESTADEST = Null;
            SET @V_MUNIDEST = Null;

            SELECT @V_PAISDEST = CDPAIS, @V_ESTADEST = SGESTADO, @V_MUNIDEST = CDMUNICIPIO
            FROM ENDEFILI
            WHERE CDFILIAL     = @V_CDFILIRECE AND
                  IDTPENDEFILI = @V_IDENDEMIS;
         END;
      END
      ELSE BEGIN IF @V_ORIGDESTOP = 'F' BEGIN /*DESTINATARIO -> FORNECEDOR */
            SET @V_CDORIGDESTNF = @V_CDFORNECED;

            SET @V_IDENDCFOP = 'P';
            SET @V_IDENDEMIS = 'P';

            SELECT @V_IDENDCFOP = ISNULL(IDENDCFOPFOR,'P'), @V_IDENDEMIS = ISNULL(IDENDEMISFOR,'P')
            FROM FORNECEDOR
            WHERE (CDFORNECED = @V_CDORIGDESTNF);

            SET @V_PAISDEST = Null;
            SET @V_ESTADEST = Null;
            SET @V_MUNIDEST = Null;

            SELECT @V_PAISDEST = CDPAIS, @V_ESTADEST = SGESTADO, @V_MUNIDEST = CDMUNICIPIO
            FROM ENDEFORN
            WHERE (CDFORNECED   = @V_CDORIGDESTNF) AND
                  (IDTPENDEFORN = @V_IDENDEMIS);
         END
         ELSE BEGIN /*DESTINATARIO -> CLIENTE(DEFAULT) */
            SET @V_CDORIGDESTNF = @V_CDCLIENTE;

            SET @V_IDENDCFOP = 'P';
            SET @V_IDENDEMIS = 'P';

            SELECT @V_IDENDCFOP = ISNULL(IDENDCFOPCLI,'P'), @V_IDENDEMIS = ISNULL(IDENDEMISCLI,'P')
            FROM CLIENTE
            WHERE (CDCLIENTE = @V_CDORIGDESTNF);

            IF @V_IDENDCFOP = 'I' BEGIN
               SET @V_PAISDEST = Null;
               SET @V_ESTADEST = Null;
               SET @V_MUNIDEST = Null;

               SELECT @V_PAISDEST = CDPAIS, @V_ESTADEST = SGESTADO, @V_MUNIDEST = CDMUNICIPIO
               FROM INSCRESTAD
               WHERE CDEMPRESA  = @P_EMPRESA AND
                     CDINSCESTA = @P_INSCESTA;
            END
            ELSE BEGIN
               SET @V_PAISDEST = Null;
               SET @V_ESTADEST = Null;
               SET @V_MUNIDEST = Null;

               SELECT @V_PAISDEST = CDPAIS, @V_ESTADEST = SGESTADO, @V_MUNIDEST = CDMUNICIPIO
               FROM ENDECLIE
               WHERE (CDCLIENTE    = @V_CDORIGDESTNF) AND
                     (IDTPENDECLIE = @V_IDENDEMIS);
            END;
         END;
       END;
      /*
      QUANDO A OPERAO DA NOTA FISCAL FOR PRESENCIAL O SISTEMA USAR COMO ENDEREO
      DE DESTINO O MESMO ENDEREO DA ORIGEM. EST CONDIO FOI NECESSRIA PARA ATENDER 
      A NOTA TCNICA 2015/003
      */
      IF @V_IDPRESENCIAL = '1' BEGIN
         SET @V_PAISDEST = @V_PAISORIG;
         SET @V_ESTADEST = @V_ESTAORIG;
         SET @V_MUNIDEST = @V_MUNIORIG;
      END;
   END;

   IF (@P_ENTSAICST = 'E') BEGIN
      SET @V_IDENDCFOP  = 'I';
      SET @V_CDEMPRESA  = Null;
      SET @V_CDINSCESTA = Null;

      SELECT @V_IDENDCFOP = ISNULL(IDENDCFOPFIL,'I'), @V_CDEMPRESA = CDEMPRESA, @V_CDINSCESTA = CDINSCESTA
      FROM FILIAL
      WHERE (CDFILIAL = @V_CDFILIRECE);

      SET @V_PAISDEST = Null;
      SET @V_ESTADEST = Null;
      SET @V_MUNIDEST = Null;

      SELECT @V_PAISDEST = CDPAIS, @V_ESTADEST = SGESTADO, @V_MUNIDEST = CDMUNICIPIO
      FROM INSCRESTAD
      WHERE CDEMPRESA  = @P_EMPRESA AND
            CDINSCESTA = @P_INSCESTA;

      IF @V_IDNFPRESTSERV = 'S' BEGIN
         SET @V_PAISDEST = NULL;
         SET @V_ESTADEST = NULL;
         SET @V_MUNIDEST = NULL;

         SELECT @V_PAISDEST = MAX(CDPAIS), @V_ESTADEST = MAX(SGESTADO), @V_MUNIDEST = MAX(CDMUNICIPIO)
           FROM ENDEFILI
          WHERE (CDFILIAL     = @V_CDFILIRECE) AND
                (IDTPENDEFILI = 'P');
      END;

      /*DESTINATRIO-REMETENTE DA NOTA*/
      IF @V_IDORIGDESTNF IS NULL BEGIN
         SET @V_ORIGDESTOP = Null;

         SELECT @V_ORIGDESTOP = ISNULL(IDORIGDESTOP, 'F')
         FROM TIPOOPERAC
         WHERE IDENTRSAIDOP = 'E' AND
              CDTIPOOPER   = @P_TIPOOPER;
      END
      ELSE BEGIN
        SET @V_ORIGDESTOP = @V_IDORIGDESTNF;
      END;

      IF @V_ORIGDESTOP = 'L' BEGIN /*Remetente -> FILIAL */
         SET @V_CDORIGDESTNF = @V_CDFILIEMIT;

         SET @V_IDENDCFOP  = 'I';
         SET @V_IDENDEMIS  = 'I';
         SET @V_CDEMPRESA  = Null;
         SET @V_CDINSCESTA = Null;

         SELECT @V_IDENDCFOP = ISNULL(IDENDCFOPFIL,'I'), @V_IDENDEMIS = ISNULL(IDENDEMISFIL,'I'),
                @V_CDEMPRESA = CDEMPRESA, @V_CDINSCESTA = CDINSCESTA
         FROM FILIAL
         WHERE (CDFILIAL = @V_CDFILIEMIT);

         IF @V_IDENDEMIS = 'I' BEGIN
            SET @V_PAISORIG = Null;
            SET @V_ESTAORIG = Null;
            SET @V_MUNIORIG = Null;

            SELECT @V_PAISORIG = CDPAIS, @V_ESTAORIG = SGESTADO, @V_MUNIORIG = CDMUNICIPIO
            FROM INSCRESTAD
            WHERE CDEMPRESA  = @V_CDEMPRESA AND
                  CDINSCESTA = @V_CDINSCESTA;
         END
         ELSE BEGIN
            SET @V_PAISORIG = Null;
            SET @V_ESTAORIG = Null;
            SET @V_MUNIORIG = Null;

            SELECT @V_PAISORIG = CDPAIS, @V_ESTAORIG = SGESTADO, @V_MUNIORIG = CDMUNICIPIO
            FROM ENDEFILI
            WHERE CDFILIAL     = @V_CDFILIEMIT AND
                  IDTPENDEFILI = @V_IDENDEMIS;
         END;
      END
      ELSE BEGIN
         IF @V_ORIGDESTOP = 'F' BEGIN /*DESTINATARIO -> FORNECEDOR */
            SET @V_CDORIGDESTNF = @V_CDFORNECED;

            SET @V_IDENDCFOP = 'P';
            SET @V_IDENDEMIS = 'P';

            SELECT @V_IDENDCFOP = ISNULL(IDENDCFOPFOR,'P'), @V_IDENDEMIS = ISNULL(IDENDEMISFOR,'P')
            FROM FORNECEDOR
            WHERE (CDFORNECED = @V_CDORIGDESTNF);

            SET @V_PAISORIG = Null;
            SET @V_ESTAORIG = Null;
            SET @V_MUNIORIG = Null;

            SELECT @V_PAISORIG = CDPAIS, @V_ESTAORIG = SGESTADO, @V_MUNIORIG = CDMUNICIPIO
            FROM ENDEFORN
            WHERE (CDFORNECED   = @V_CDORIGDESTNF) AND
                  (IDTPENDEFORN = @V_IDENDCFOP);
         END
         ELSE BEGIN /*DESTINATARIO -> CLIENTE */
            SET @V_CDORIGDESTNF = @V_CDCLIENTE;

            SET @V_IDENDCFOP = 'P';
            SET @V_IDENDEMIS = 'P';

            SELECT @V_IDENDCFOP = ISNULL(IDENDCFOPCLI,'P'), @V_IDENDEMIS = ISNULL(IDENDEMISCLI,'P')
            FROM CLIENTE
            WHERE (CDCLIENTE = @V_CDORIGDESTNF);

            IF @V_IDENDCFOP = 'I' BEGIN
               SET @V_PAISORIG = Null;
               SET @V_ESTAORIG = Null;
               SET @V_MUNIORIG = Null;

               SELECT @V_PAISORIG = CDPAIS, @V_ESTAORIG = SGESTADO, @V_MUNIORIG = CDMUNICIPIO
               FROM INSCRESTAD
               WHERE CDEMPRESA  = @P_EMPRESA AND
                     CDINSCESTA = @P_INSCESTA;
            END
            ELSE BEGIN
               SET @V_PAISORIG = Null;
               SET @V_ESTAORIG = Null;
               SET @V_MUNIORIG = Null;

               SELECT @V_PAISORIG = CDPAIS, @V_ESTAORIG = SGESTADO, @V_MUNIORIG = CDMUNICIPIO
               FROM ENDECLIE
               WHERE (CDCLIENTE    = @V_CDORIGDESTNF) AND
                     (IDTPENDECLIE = @V_IDENDEMIS);
            END;
         END;
      END;
   END;

   DECLARE C_REGRA CURSOR FOR
      SELECT CDSITUTRIB, IDCSTINTEREST, CDREGRAFISC
        FROM TEKNISA.CONSULTA_REGRA_FISCAL('00', @P_EMPRESA, @P_CDGRUPOFISC, @P_ENTSAICST, @P_TIPOOPER, @P_INSCESTA, @P_CDARVPROD, @V_INIVALID,
                                           @V_PAISORIG, @V_ESTAORIG, @V_MUNIORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_VRITEM, 'N', @P_IDORIGEMPROD)
       WHERE VRALIQUOTA IS NOT NULL;

   OPEN C_REGRA;
   FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDSITUTRIB, @V_REGRA_IDCSTINTEREST, @V_REGRA_CDREGRAFISC;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP, CDREGRATMP)
                  VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_REGRA_CDSITUTRIB, NULL, ISNULL(@V_REGRA_IDCSTINTEREST, 'T'), @V_REGRA_CDREGRAFISC);

      SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2)
      FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDSITUTRIB, @V_REGRA_IDCSTINTEREST, @V_REGRA_CDREGRAFISC;
   END;
   CLOSE C_REGRA;
   DEALLOCATE C_REGRA;

   /* Verificao do cst referente ao imposto 00 se h filiais parametrizadas na tela Parmetros de Grupo Fiscal (Imposto/Filial) */
   DECLARE C_IMPFILI CURSOR FOR SELECT G.CDIMPOSTO, G.CDGRUPOFISC
                                  FROM GRUPOFISCIMPFIL G,
                                       (SELECT CASE @P_ENTSAICST WHEN 'E' THEN CDFILIRECE ELSE CDFILIEMIT END AS CDFILIAL
                                          FROM NOTAFISCAL
                                         WHERE CDFILIAL = @P_FILIAL
                                           AND NRLANCTONF = @P_LANCTONF
                                          AND @P_IDSISTEMA IS NULL
                                        UNION ALL
                                        SELECT CDFILIAL
                                          FROM PEDIDO
                                         WHERE CDFILIAL = SUBSTRING(@P_FILIAL,1,4)
                                           AND NRPEDIDO = SUBSTRING(@P_FILIAL,5,10)
                                           AND @P_IDSISTEMA = 'PED') F
                                 WHERE G.CDFILIAL = F.CDFILIAL
                                   AND NOT G.CDGRUPOFISC IS NULL;
   OPEN C_IMPFILI;
   FETCH NEXT FROM C_IMPFILI INTO @V_IMPFILI_CDIMPOSTO, @V_IMPFILI_CDGRUPOFISC;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      DECLARE C_REGRA CURSOR FOR
      SELECT CDSITUTRIB, IDCSTINTEREST, CDREGRAFISC
        FROM TEKNISA.CONSULTA_REGRA_FISCAL('00', @P_EMPRESA, @V_IMPFILI_CDGRUPOFISC, @P_ENTSAICST, @P_TIPOOPER, @P_INSCESTA, @P_CDARVPROD, @V_INIVALID,
                                           @V_PAISORIG, @V_ESTAORIG, @V_MUNIORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_VRITEM, 'N', @P_IDORIGEMPROD)
       WHERE VRALIQUOTA IS NOT NULL;

      OPEN C_REGRA;
      FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDSITUTRIB, @V_REGRA_IDCSTINTEREST, @V_REGRA_CDREGRAFISC;
      WHILE (@@FETCH_STATUS = 0) BEGIN

         SELECT @V_EXISTE = COUNT(*)
           FROM CSTTEMP
          WHERE NRCSTTEMP  = @P_FILIAL+@P_LANCTONF
            AND CDREGRATMP IS NOT NULL;

         IF @V_EXISTE > 0 BEGIN
            DELETE FROM CSTTEMP
            WHERE NRCSTTEMP  = @P_FILIAL+@P_LANCTONF;
         END;

         INSERT INTO CSTTEMP(NRCSTTEMP,            NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP, CDREGRATMP)
                      VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_REGRA_CDSITUTRIB, NULL, ISNULL(@V_REGRA_IDCSTINTEREST, 'T'), @V_REGRA_CDREGRAFISC);


         SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2)
         FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDSITUTRIB, @V_REGRA_IDCSTINTEREST, @V_REGRA_CDREGRAFISC;
      END;
      CLOSE C_REGRA;
      DEALLOCATE C_REGRA;

      FETCH NEXT FROM C_IMPFILI INTO @V_IMPFILI_CDIMPOSTO, @V_IMPFILI_CDGRUPOFISC;
   END;
   CLOSE C_IMPFILI;
   DEALLOCATE C_IMPFILI;

   /* Verificao das incidncias referente as filiais parametrizadas na tela Parmetros de Grupo Fiscal (Imposto/Inscrio Estadual) */
   /* Por Fornecedor */
   DECLARE C_IMPINSCESTAFO CURSOR FOR SELECT G.CDIMPOSTO, G.CDGRUPOFISC
                                        FROM GRFISIMPIEFORN G,
                                            (SELECT CDFORNECED
                                               FROM NOTAFISCAL
                                              WHERE CDFILIAL = @P_FILIAL
                                                AND NRLANCTONF = @P_LANCTONF) N
                                       WHERE G.CDFORNECED = N.CDFORNECED
                                         AND G.CDEMPRESA = @P_EMPRESA
                                         AND G.CDINSCESTA = @P_INSCESTA
                                         AND NOT G.CDGRUPOFISC IS NULL;
   OPEN C_IMPINSCESTAFO;
   FETCH NEXT FROM C_IMPINSCESTAFO INTO @V_IMPINSCESTAFO_CDIMPOSTO, @V_IMPINSCESTAFO_CDGRUPOFISC;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      DECLARE C_REGRA CURSOR FOR
      SELECT CDSITUTRIB, IDCSTINTEREST, CDREGRAFISC
        FROM TEKNISA.CONSULTA_REGRA_FISCAL('00', @P_EMPRESA, @V_IMPINSCESTAFO_CDGRUPOFISC, @P_ENTSAICST, @P_TIPOOPER, @P_INSCESTA, @P_CDARVPROD, @V_INIVALID,
                                           @V_PAISORIG, @V_ESTAORIG, @V_MUNIORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_VRITEM, 'N', @P_IDORIGEMPROD)
       WHERE VRALIQUOTA IS NOT NULL;
      OPEN C_REGRA;
      FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDSITUTRIB, @V_REGRA_IDCSTINTEREST, @V_REGRA_CDREGRAFISC;
      WHILE (@@FETCH_STATUS = 0) BEGIN
         IF @V_EXISTE > 0 BEGIN
            DELETE FROM CSTTEMP
            WHERE NRCSTTEMP  = @P_FILIAL+@P_LANCTONF
              AND CDREGRATMP IS NOT NULL;
         END;

         INSERT INTO CSTTEMP(NRCSTTEMP,            NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP, CDREGRATMP)
                      VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_REGRA_CDSITUTRIB, NULL, ISNULL(@V_REGRA_IDCSTINTEREST, 'T'), @V_REGRA_CDREGRAFISC);


         SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2)
         FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDSITUTRIB, @V_REGRA_IDCSTINTEREST, @V_REGRA_CDREGRAFISC;
      END;
      CLOSE C_REGRA;
      DEALLOCATE C_REGRA;

      FETCH NEXT FROM C_IMPINSCESTAFO INTO @V_IMPINSCESTAFO_CDIMPOSTO, @V_IMPINSCESTAFO_CDGRUPOFISC;
   END;
   CLOSE C_IMPINSCESTAFO;
   DEALLOCATE C_IMPINSCESTAFO;


   /* Verificao das incidncias referente as filiais parametrizadas na tela Parmetros de Grupo Fiscal (Imposto/Inscrio Estadual) */
   /* Por Cliente */
   DECLARE C_IMPINSCESTACL CURSOR FOR SELECT G.CDIMPOSTO, G.CDGRUPOFISC
                                        FROM GRFISIMPIECLIE G,
                                            (SELECT CDCLIENTE
                                               FROM NOTAFISCAL
                                              WHERE CDFILIAL = @P_FILIAL
                                                AND NRLANCTONF = @P_LANCTONF) N
                                       WHERE G.CDCLIENTE = N.CDCLIENTE
                                         AND G.CDEMPRESA = @P_EMPRESA
                                         AND G.CDINSCESTA = @P_INSCESTA
                                         AND NOT G.CDGRUPOFISC IS NULL;
   OPEN C_IMPINSCESTACL;
   FETCH NEXT FROM C_IMPINSCESTACL INTO @V_IMPINSCESTACL_CDIMPOSTO, @V_IMPINSCESTACL_CDGRUPOFISC;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      DECLARE C_REGRA CURSOR FOR
      SELECT CDSITUTRIB, IDCSTINTEREST, CDREGRAFISC
        FROM TEKNISA.CONSULTA_REGRA_FISCAL('00', @P_EMPRESA, @V_IMPINSCESTACL_CDGRUPOFISC, @P_ENTSAICST, @P_TIPOOPER, @P_INSCESTA, @P_CDARVPROD, @V_INIVALID,
                                           @V_PAISORIG, @V_ESTAORIG, @V_MUNIORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_VRITEM, 'N', @P_IDORIGEMPROD)
       WHERE VRALIQUOTA IS NOT NULL;

      OPEN C_REGRA;
      FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDSITUTRIB, @V_REGRA_IDCSTINTEREST, @V_REGRA_CDREGRAFISC;
      WHILE (@@FETCH_STATUS = 0) BEGIN

         IF @V_EXISTE > 0 BEGIN
            DELETE FROM CSTTEMP
            WHERE NRCSTTEMP  = @P_FILIAL+@P_LANCTONF
              AND CDREGRATMP IS NOT NULL;
         END;

         INSERT INTO CSTTEMP(NRCSTTEMP,            NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                      VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_REGRA_CDSITUTRIB, NULL, ISNULL(@V_REGRA_IDCSTINTEREST, 'T'));


         SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2)

         FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDSITUTRIB, @V_REGRA_IDCSTINTEREST, @V_REGRA_CDREGRAFISC;
      END;
      CLOSE C_REGRA;
      DEALLOCATE C_REGRA;

      FETCH NEXT FROM C_IMPINSCESTACL INTO @V_IMPINSCESTACL_CDIMPOSTO, @V_IMPINSCESTACL_CDGRUPOFISC;
   END;
   CLOSE C_IMPINSCESTACL;
   DEALLOCATE C_IMPINSCESTACL;

   SET @V_EXISTE = 0;
   SELECT @V_EXISTE = COUNT(*)
     FROM CSTTEMP
    WHERE NRCSTTEMP  = @P_FILIAL+@P_LANCTONF
      AND CDREGRATMP IS NOT NULL;

   IF NOT(@V_EXISTE > 0) BEGIN
      IF (@P_IDCSTINTERNA = 'S') BEGIN
         SELECT @V_CONTINTERNA = COUNT(*)
         FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
         WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
               (CDEMPRESA       = @P_EMPRESA)         AND
               (CDTIPOOPER      = @P_TIPOOPER)        AND
               (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
               (C.IDCSTINTEREST = 'N')                AND
               (C.IDCSTINTERNA  = 'S')                AND
               (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);

         IF @V_CONTINTERNA > 0 BEGIN
            IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
               SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
               FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
               WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                     (CDEMPRESA       = @P_EMPRESA)         AND
                     (CDTIPOOPER      = @P_TIPOOPER)        AND
                     (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                     (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                     (C.IDCSTINTEREST = 'N')                AND
                     (C.IDCSTINTERNA  = 'S')                AND
                     (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);


               IF @V_CONTADOR > 0 BEGIN
                  IF NOT(@V_CDARVPROD IS NULL)
                  BEGIN
                     DECLARE C_CST CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                           LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                          WHERE
                              (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                              (C.IDCSTINTEREST = 'N')                AND
                              (C.IDCSTINTERNA  = 'S')                AND
                              (P.CDARVPROD     = @V_CDARVPROD);

                     OPEN C_CST;

                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'I');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;

                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END
                  ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST  = M.NRINCIDCST)
                        WHERE	(C.IDENTSAICST = @P_ENTSAICST)      AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                              (C.IDCSTINTEREST = 'N')                AND
                              (C.IDCSTINTERNA  = 'S')                AND
                              (C.CDPRODUTO IS NULL);

                     OPEN C_CSTNULL;

                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'I');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END
            ELSE BEGIN
               SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
               FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
               WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                     (CDEMPRESA       = @P_EMPRESA)         AND
                     (CDTIPOOPER      = @P_TIPOOPER)        AND
                     (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                     (CDGRUPOFISC IS NULL)                  AND
                     (C.IDCSTINTEREST = 'N')                AND
                     (C.IDCSTINTERNA  = 'S')                AND
                     (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);

               IF NOT(@V_CDARVPROD IS NULL) BEGIN
                  DECLARE C_CST CURSOR FOR
                     SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                     FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                        LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                     WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                           (C.CDEMPRESA     = @P_EMPRESA)         AND
                           (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                           (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                           (C.CDGRUPOFISC IS NULL)                AND
                           (C.IDCSTINTEREST = 'N')                AND
                           (C.IDCSTINTERNA  = 'S')                AND
                           (P.CDARVPROD   = @V_CDARVPROD);

                  OPEN C_CST;

                  FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                  WHILE (@@FETCH_STATUS = 0) BEGIN

                     IF (@V_CST1DIGT IS NULL ) BEGIN
                        SET @V_CST1DIGT = '';
                     END;

                     SELECT @V_COUNTMENS = COUNT(*)
                       FROM MENSAGEM
                      WHERE CDMENSAGEM = @V_CDMENSAGEM
                        AND IDSITUACAOMENS = 'I';

                     IF @V_COUNTMENS > 0 BEGIN
                        SET @V_DSMENSCST = NULL;
                     END;

                     INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                     VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'I');

                     SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                  END;
                  CLOSE C_CST;
                  DEALLOCATE C_CST;
               END
               ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                  DECLARE C_CSTNULL CURSOR FOR
                     SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                     FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                     WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                           (C.CDEMPRESA     = @P_EMPRESA)         AND
                           (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                           (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                           (C.CDGRUPOFISC IS NULL)                AND
                           (C.IDCSTINTEREST = 'N')                AND
                           (C.IDCSTINTERNA  = 'S')                AND
                           (C.CDPRODUTO IS NULL);

                  OPEN C_CSTNULL;

                  FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                  WHILE (@@FETCH_STATUS = 0) BEGIN

                     IF (@V_CST1DIGT IS NULL ) BEGIN
                        SET @V_CST1DIGT = '';
                     END;

                     SELECT @V_COUNTMENS = COUNT(*)
                       FROM MENSAGEM
                      WHERE CDMENSAGEM = @V_CDMENSAGEM
                        AND IDSITUACAOMENS = 'I';

                     IF @V_COUNTMENS > 0 BEGIN
                        SET @V_DSMENSCST = NULL;
                     END;

                     INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                     VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'I');

                     SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                  END;
                  CLOSE C_CSTNULL;
                  DEALLOCATE C_CSTNULL;
               END;
            END;
         END;
         ELSE BEGIN
            SELECT @V_CONTINTEREST = COUNT(*)
            FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
            WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                  (CDEMPRESA       = @P_EMPRESA)         AND
                  (CDTIPOOPER      = @P_TIPOOPER)        AND
                  (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                  (C.IDCSTINTEREST = 'S')                AND
                  (C.IDCSTINTERNA  = 'N')                AND
                  (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);

            IF @V_CONTINTEREST > 0 BEGIN
               IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE (IDENTSAICST     = @P_ENTSAICST)        AND
                        (CDEMPRESA       = @P_EMPRESA)          AND
                        (CDTIPOOPER      = @P_TIPOOPER)         AND
                        (CDINSCESTA      = RTRIM(@P_INSCESTA))  AND
                        (CDGRUPOFISC     = @P_CDGRUPOFISC)      AND
                        (IDCSTINTEREST   = 'S')                 AND
                        (C.IDCSTINTERNA  = 'N')                 AND
                        (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);


                  IF @V_CONTADOR > 0 BEGIN
                     IF NOT(@V_CDARVPROD IS NULL)
                     BEGIN
                        DECLARE C_CST CURSOR FOR
                           SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                           FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                              LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                             WHERE
                                 (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                 (C.CDEMPRESA     = @P_EMPRESA)         AND
                                 (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                 (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                 (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                 (C.IDCSTINTEREST = 'S')                AND
                                 (C.IDCSTINTERNA  = 'N')                AND
                                 (P.CDARVPROD     = @V_CDARVPROD);

                        OPEN C_CST;

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                        WHILE (@@FETCH_STATUS = 0) BEGIN

                           IF (@V_CST1DIGT IS NULL ) BEGIN
                              SET @V_CST1DIGT = '';
                           END;

                           SELECT @V_COUNTMENS = COUNT(*)
                             FROM MENSAGEM
                            WHERE CDMENSAGEM = @V_CDMENSAGEM
                              AND IDSITUACAOMENS = 'I';

                           IF @V_COUNTMENS > 0 BEGIN
                              SET @V_DSMENSCST = NULL;
                           END;

                           INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                           VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'T');

                           SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                        END;

                        CLOSE C_CST;
                        DEALLOCATE C_CST;
                     END
                     ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CSTNULL CURSOR FOR
                           SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                           FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST  = M.NRINCIDCST)
                           WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                 (C.CDEMPRESA     = @P_EMPRESA)         AND
                                 (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                 (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                 (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                 (C.IDCSTINTEREST = 'S')                AND
                                 (C.IDCSTINTERNA  = 'N')                AND
                                 (C.CDPRODUTO IS NULL);

                        OPEN C_CSTNULL;

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                        WHILE (@@FETCH_STATUS = 0) BEGIN

                           IF (@V_CST1DIGT IS NULL ) BEGIN
                              SET @V_CST1DIGT = '';
                           END;

                           SELECT @V_COUNTMENS = COUNT(*)
                             FROM MENSAGEM
                            WHERE CDMENSAGEM = @V_CDMENSAGEM
                              AND IDSITUACAOMENS = 'I';

                           IF @V_COUNTMENS > 0 BEGIN
                              SET @V_DSMENSCST = NULL;
                           END;

                           INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                           VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'T');

                           SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                        END;
                        CLOSE C_CSTNULL;
                        DEALLOCATE C_CSTNULL;
                     END;
                  END;
               END
               ELSE BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                        (CDEMPRESA       = @P_EMPRESA)         AND
                        (CDTIPOOPER      = @P_TIPOOPER)        AND
                        (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                        (CDGRUPOFISC IS NULL)                  AND
                        (IDCSTINTEREST   = 'S')                AND
                        (C.IDCSTINTERNA  = 'N')                AND
                        (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);

                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                           LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                        WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC IS NULL)                AND
                              (C.IDCSTINTEREST = 'S')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (P.CDARVPROD     = @V_CDARVPROD);

                     OPEN C_CST;

                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'T');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END
                  ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                        WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC IS NULL)                AND
                              (C.IDCSTINTEREST = 'S')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (C.CDPRODUTO IS NULL);

                     OPEN C_CSTNULL;

                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'T');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END
            ELSE BEGIN
               IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                        (CDEMPRESA       = @P_EMPRESA)         AND
                        (CDTIPOOPER      = @P_TIPOOPER)        AND
                        (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                        (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                        (C.IDCSTINTEREST = 'N')                AND
                        (C.IDCSTINTERNA  = 'N')                AND
                        (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);


                  IF @V_CONTADOR > 0 BEGIN
                     IF NOT(@V_CDARVPROD IS NULL)
                     BEGIN
                        DECLARE C_CST CURSOR FOR
                           SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                           FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                              LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                             WHERE
                                 (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                 (C.CDEMPRESA     = @P_EMPRESA)         AND
                                 (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                 (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                 (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                 (C.IDCSTINTEREST = 'N')                AND
                                 (C.IDCSTINTERNA  = 'N')                AND
                                 (P.CDARVPROD     = @V_CDARVPROD);

                        OPEN C_CST;

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                        WHILE (@@FETCH_STATUS = 0) BEGIN

                           IF (@V_CST1DIGT IS NULL ) BEGIN
                              SET @V_CST1DIGT = '';
                           END;

                           SELECT @V_COUNTMENS = COUNT(*)
                             FROM MENSAGEM
                            WHERE CDMENSAGEM = @V_CDMENSAGEM
                              AND IDSITUACAOMENS = 'I';

                           IF @V_COUNTMENS > 0 BEGIN
                              SET @V_DSMENSCST = NULL;
                           END;

                           INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                           VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'E');

                           SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                        END;

                        CLOSE C_CST;
                        DEALLOCATE C_CST;
                     END
                     ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CSTNULL CURSOR FOR
                           SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                           FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST  = M.NRINCIDCST)
                           WHERE	(C.IDENTSAICST   = @P_ENTSAICST)       AND
                                 (C.CDEMPRESA     = @P_EMPRESA)         AND
                                 (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                 (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                 (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                 (C.IDCSTINTEREST = 'N')                AND
                                 (C.IDCSTINTERNA  = 'N')                AND
                                 (C.CDPRODUTO IS NULL);

                        OPEN C_CSTNULL;

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                        WHILE (@@FETCH_STATUS = 0) BEGIN

                           IF (@V_CST1DIGT IS NULL ) BEGIN
                              SET @V_CST1DIGT = '';
                           END;

                           SELECT @V_COUNTMENS = COUNT(*)
                             FROM MENSAGEM
                            WHERE CDMENSAGEM = @V_CDMENSAGEM
                              AND IDSITUACAOMENS = 'I';

                           IF @V_COUNTMENS > 0 BEGIN
                              SET @V_DSMENSCST = NULL;
                           END;

                           INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                           VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'E');

                           SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                        END;
                        CLOSE C_CSTNULL;
                        DEALLOCATE C_CSTNULL;
                     END;
                  END;
               END
               ELSE BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO   = P.CDPRODUTO)
                  WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                        (CDEMPRESA       = @P_EMPRESA)         AND
                        (CDTIPOOPER      = @P_TIPOOPER)        AND
                        (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                        (CDGRUPOFISC IS NULL)                  AND
                        (C.IDCSTINTEREST = 'N')                AND
                        (C.IDCSTINTERNA  = 'N')                AND
                        (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);

                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                           LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                        WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC IS NULL)                AND
                              (C.IDCSTINTEREST = 'N')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (P.CDARVPROD     = @V_CDARVPROD);

                     OPEN C_CST;

                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'E');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END
                  ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                        WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC IS NULL)                AND
                              (C.IDCSTINTEREST = 'N')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (C.CDPRODUTO IS NULL);

                     OPEN C_CSTNULL;

                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'E');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END;
         END;
      END;
      ELSE BEGIN
         IF (@P_IDCSTINTEREST = 'S') BEGIN
            SELECT @V_CONTINTEREST = COUNT(*)
            FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
            WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                  (CDEMPRESA       = @P_EMPRESA)         AND
                  (CDTIPOOPER      = @P_TIPOOPER)        AND
                  (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                  (C.IDCSTINTEREST = 'S')                AND
                  (C.IDCSTINTERNA  = 'N')                AND
                  (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);

            IF @V_CONTINTEREST > 0 BEGIN
               IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE (IDENTSAICST     = @P_ENTSAICST)        AND
                        (CDEMPRESA       = @P_EMPRESA)          AND
                        (CDTIPOOPER      = @P_TIPOOPER)         AND
                        (CDINSCESTA      = RTRIM(@P_INSCESTA))  AND
                        (CDGRUPOFISC     = @P_CDGRUPOFISC)      AND
                        (IDCSTINTEREST   = 'S')                 AND
                        (C.IDCSTINTERNA  = 'N')                 AND
                        (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);


                  IF @V_CONTADOR > 0 BEGIN
                     IF NOT(@V_CDARVPROD IS NULL)
                     BEGIN
                        DECLARE C_CST CURSOR FOR
                           SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                           FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                              LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                             WHERE
                                 (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                 (C.CDEMPRESA     = @P_EMPRESA)         AND
                                 (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                 (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                 (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                 (C.IDCSTINTEREST = 'S')                AND
                                 (C.IDCSTINTERNA  = 'N')                AND
                                 (P.CDARVPROD     = @V_CDARVPROD);

                        OPEN C_CST;

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                        WHILE (@@FETCH_STATUS = 0) BEGIN

                           IF (@V_CST1DIGT IS NULL ) BEGIN
                              SET @V_CST1DIGT = '';
                           END;

                           SELECT @V_COUNTMENS = COUNT(*)
                             FROM MENSAGEM
                            WHERE CDMENSAGEM = @V_CDMENSAGEM
                              AND IDSITUACAOMENS = 'I';

                           IF @V_COUNTMENS > 0 BEGIN
                              SET @V_DSMENSCST = NULL;
                           END;

                           INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                           VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'T');

                           SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                        END;

                        CLOSE C_CST;
                        DEALLOCATE C_CST;
                     END
                     ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CSTNULL CURSOR FOR
                           SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                           FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST  = M.NRINCIDCST)
                           WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                 (C.CDEMPRESA     = @P_EMPRESA)         AND
                                 (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                 (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                 (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                 (C.IDCSTINTEREST = 'S')                AND
                                 (C.IDCSTINTERNA  = 'N')                AND
                                 (C.CDPRODUTO IS NULL);

                        OPEN C_CSTNULL;

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                        WHILE (@@FETCH_STATUS = 0) BEGIN

                           IF (@V_CST1DIGT IS NULL ) BEGIN
                              SET @V_CST1DIGT = '';
                           END;

                           SELECT @V_COUNTMENS = COUNT(*)
                             FROM MENSAGEM
                            WHERE CDMENSAGEM = @V_CDMENSAGEM
                              AND IDSITUACAOMENS = 'I';

                           IF @V_COUNTMENS > 0 BEGIN
                              SET @V_DSMENSCST = NULL;
                           END;

                           INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                           VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'T');

                           SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                        END;
                        CLOSE C_CSTNULL;
                        DEALLOCATE C_CSTNULL;
                     END;
                  END;
               END
               ELSE BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                        (CDEMPRESA       = @P_EMPRESA)         AND
                        (CDTIPOOPER      = @P_TIPOOPER)        AND
                        (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                        (CDGRUPOFISC IS NULL)                  AND
                        (IDCSTINTEREST   = 'S')                AND
                        (C.IDCSTINTERNA  = 'N')                AND
                        (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);

                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                           LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                        WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC IS NULL)                AND
                              (C.IDCSTINTEREST = 'S')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (P.CDARVPROD     = @V_CDARVPROD);

                     OPEN C_CST;

                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'T');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END
                  ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                        WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC IS NULL)                AND
                              (C.IDCSTINTEREST = 'S')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (C.CDPRODUTO IS NULL);

                     OPEN C_CSTNULL;

                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'T');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END;
            ELSE BEGIN
               IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                        (CDEMPRESA       = @P_EMPRESA)         AND
                        (CDTIPOOPER      = @P_TIPOOPER)        AND
                        (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                        (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                        (C.IDCSTINTEREST = 'N')                AND
                        (C.IDCSTINTERNA  = 'N')                AND
                        (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);


                  IF @V_CONTADOR > 0 BEGIN
                     IF NOT(@V_CDARVPROD IS NULL)
                     BEGIN
                        DECLARE C_CST CURSOR FOR
                           SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                           FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                              LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                             WHERE
                                 (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                 (C.CDEMPRESA     = @P_EMPRESA)         AND
                                 (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                 (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                 (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                 (C.IDCSTINTEREST = 'N')                AND
                                 (C.IDCSTINTERNA  = 'N')                AND
                                 (P.CDARVPROD     = @V_CDARVPROD);

                        OPEN C_CST;

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                        WHILE (@@FETCH_STATUS = 0) BEGIN

                           IF (@V_CST1DIGT IS NULL ) BEGIN
                              SET @V_CST1DIGT = '';
                           END;

                           SELECT @V_COUNTMENS = COUNT(*)
                             FROM MENSAGEM
                            WHERE CDMENSAGEM = @V_CDMENSAGEM
                              AND IDSITUACAOMENS = 'I';

                           IF @V_COUNTMENS > 0 BEGIN
                              SET @V_DSMENSCST = NULL;
                           END;

                           INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                           VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'E');

                           SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                        END;

                        CLOSE C_CST;
                        DEALLOCATE C_CST;
                     END
                     ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CSTNULL CURSOR FOR
                           SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                           FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST  = M.NRINCIDCST)
                           WHERE	(C.IDENTSAICST   = @P_ENTSAICST)       AND
                                 (C.CDEMPRESA     = @P_EMPRESA)         AND
                                 (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                 (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                 (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                 (C.IDCSTINTEREST = 'N')                AND
                                 (C.IDCSTINTERNA  = 'N')                AND
                                 (C.CDPRODUTO IS NULL);

                        OPEN C_CSTNULL;

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                        WHILE (@@FETCH_STATUS = 0) BEGIN

                           IF (@V_CST1DIGT IS NULL ) BEGIN
                              SET @V_CST1DIGT = '';
                           END;

                           SELECT @V_COUNTMENS = COUNT(*)
                             FROM MENSAGEM
                            WHERE CDMENSAGEM = @V_CDMENSAGEM
                              AND IDSITUACAOMENS = 'I';

                           IF @V_COUNTMENS > 0 BEGIN
                              SET @V_DSMENSCST = NULL;
                           END;

                           INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                           VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'E');

                           SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                        END;
                        CLOSE C_CSTNULL;
                        DEALLOCATE C_CSTNULL;
                     END;
                  END;
               END
               ELSE BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO   = P.CDPRODUTO)
                  WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                        (CDEMPRESA       = @P_EMPRESA)         AND
                        (CDTIPOOPER      = @P_TIPOOPER)        AND
                        (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                        (CDGRUPOFISC IS NULL)                  AND
                        (C.IDCSTINTEREST = 'N')                AND
                        (C.IDCSTINTERNA  = 'N')                AND
                        (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);

                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                           LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                        WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC IS NULL)                AND
                              (C.IDCSTINTEREST = 'N')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (P.CDARVPROD     = @V_CDARVPROD);

                     OPEN C_CST;

                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'E');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END
                  ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                        WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC IS NULL)                AND
                              (C.IDCSTINTEREST = 'N')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (C.CDPRODUTO IS NULL);

                     OPEN C_CSTNULL;

                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'E');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END;
         END;
         ELSE BEGIN
            IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
               SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
               FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
               WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                     (CDEMPRESA       = @P_EMPRESA)         AND
                     (CDTIPOOPER      = @P_TIPOOPER)        AND
                     (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                     (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                     (C.IDCSTINTEREST = 'N')                AND
                     (C.IDCSTINTERNA  = 'N')                AND
                     (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);


               IF @V_CONTADOR > 0 BEGIN
                  IF NOT(@V_CDARVPROD IS NULL)
                  BEGIN
                     DECLARE C_CST CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                           LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                          WHERE
                              (C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                              (C.IDCSTINTEREST = 'N')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (P.CDARVPROD     = @V_CDARVPROD);

                     OPEN C_CST;

                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'E');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;

                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END
                  ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR
                        SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                        FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST  = M.NRINCIDCST)
                        WHERE	(C.IDENTSAICST   = @P_ENTSAICST)       AND
                              (C.CDEMPRESA     = @P_EMPRESA)         AND
                              (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                              (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                              (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                              (C.IDCSTINTEREST = 'N')                AND
                              (C.IDCSTINTERNA  = 'N')                AND
                              (C.CDPRODUTO IS NULL);

                     OPEN C_CSTNULL;

                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        IF (@V_CST1DIGT IS NULL ) BEGIN
                           SET @V_CST1DIGT = '';
                        END;

                        SELECT @V_COUNTMENS = COUNT(*)
                          FROM MENSAGEM
                         WHERE CDMENSAGEM = @V_CDMENSAGEM
                           AND IDSITUACAOMENS = 'I';

                        IF @V_COUNTMENS > 0 BEGIN
                           SET @V_DSMENSCST = NULL;
                        END;

                        INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                        VALUES(@P_FILIAL + @P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT + @V_CDSITUTRIB, @V_DSMENSCST, 'E');

                        SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END
            ELSE BEGIN
               SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
               FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO   = P.CDPRODUTO)
               WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                     (CDEMPRESA       = @P_EMPRESA)         AND
                     (CDTIPOOPER      = @P_TIPOOPER)        AND
                     (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                     (CDGRUPOFISC IS NULL)                  AND
                     (C.IDCSTINTEREST = 'N')                AND
                     (C.IDCSTINTERNA  = 'N')                AND
                     (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);

               IF NOT(@V_CDARVPROD IS NULL) BEGIN
                  DECLARE C_CST CURSOR FOR
                     SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                     FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                        LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                     WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                           (C.CDEMPRESA     = @P_EMPRESA)         AND
                           (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                           (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                           (C.CDGRUPOFISC IS NULL)                AND
                           (C.IDCSTINTEREST = 'N')                AND
                           (C.IDCSTINTERNA  = 'N')                AND
                           (P.CDARVPROD     = @V_CDARVPROD);

                  OPEN C_CST;

                  FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                  WHILE (@@FETCH_STATUS = 0) BEGIN

                     IF (@V_CST1DIGT IS NULL ) BEGIN
                        SET @V_CST1DIGT = '';
                     END;

                     SELECT @V_COUNTMENS = COUNT(*)
                       FROM MENSAGEM
                      WHERE CDMENSAGEM = @V_CDMENSAGEM
                        AND IDSITUACAOMENS = 'I';

                     IF @V_COUNTMENS > 0 BEGIN
                        SET @V_DSMENSCST = NULL;
                     END;

                     INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                     VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'E');

                     SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                  END;
                  CLOSE C_CST;
                  DEALLOCATE C_CST;
               END
               ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                  DECLARE C_CSTNULL CURSOR FOR
                     SELECT CDSITUTRIB, DSMENSCST, CDMENSAGEM
                     FROM CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                     WHERE (C.IDENTSAICST   = @P_ENTSAICST)       AND
                           (C.CDEMPRESA     = @P_EMPRESA)         AND
                           (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                           (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                           (C.CDGRUPOFISC IS NULL)                AND
                           (C.IDCSTINTEREST = 'N')                AND
                           (C.IDCSTINTERNA  = 'N')                AND
                           (C.CDPRODUTO IS NULL);

                  OPEN C_CSTNULL;

                  FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;

                  WHILE (@@FETCH_STATUS = 0) BEGIN

                     IF (@V_CST1DIGT IS NULL ) BEGIN
                        SET @V_CST1DIGT = '';
                     END;

                     SELECT @V_COUNTMENS = COUNT(*)
                       FROM MENSAGEM
                      WHERE CDMENSAGEM = @V_CDMENSAGEM
                        AND IDSITUACAOMENS = 'I';

                     IF @V_COUNTMENS > 0 BEGIN
                        SET @V_DSMENSCST = NULL;
                     END;

                     INSERT INTO CSTTEMP(NRCSTTEMP, NRSEQUCST, CDSITTRIBTMP, DSMENSCSTTMP, IDOPERACSTTMP)
                     VALUES(@P_FILIAL+@P_LANCTONF, @V_SEQUENCIA, @V_CST1DIGT+@V_CDSITUTRIB, @V_DSMENSCST, 'E');

                     SET @V_SEQUENCIA = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(INT, @V_SEQUENCIA) + 1)),2);

                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_CDMENSAGEM;
                  END;
                  CLOSE C_CSTNULL;
                  DEALLOCATE C_CSTNULL;
               END;
            END;
         END;
      END;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CONSULTA_CST','6.05.xxx';
GO
